@@ -85,9 +85,7 @@ public:
     }
 
     void addTab(Fm::FilePath path, ViewFrame* viewFrame);
-    void addTab(Fm::FilePath path) {
-        addTab(path, activeViewFrame_);
-    }
+    void addTab(Fm::FilePath path);
 
     TabPage* currentPage(ViewFrame* viewFrame) {
         return reinterpret_cast<TabPage*>(viewFrame->getStackedWidget()->currentWidget());
@@ -283,6 +281,8 @@ private:
     // not from another window. So, we get the mode at the start and keep it.
     bool splitView_;
 
+    int splitTabsNum_; // number of tabs to be restored from the first view frame of the last window
+
     static QPointer<MainWindow> lastActive_;
 };
 
