@@ -36,7 +36,6 @@ inline static const char* bookmarkOpenMethodToString(OpenDirTargetType value);
 inline static OpenDirTargetType bookmarkOpenMethodFromString(const QString str);
 
 inline static const char* wallpaperModeToString(int value);
-inline static int wallpaperModeFromString(const QString str);
 
 inline static const char* viewModeToString(Fm::FolderView::ViewMode value);
 inline static Fm::FolderView::ViewMode viewModeFromString(const QString str);
@@ -87,6 +86,7 @@ Settings::Settings():
     showTabClose_(true),
     switchToNewTab_(false),
     reopenLastTabs_(false),
+    splitViewTabsNum_(0),
     rememberWindowSize_(true),
     fixedWindowWidth_(640),
     fixedWindowHeight_(480),
@@ -344,6 +344,7 @@ bool Settings::loadFile(QString filePath) {
     switchToNewTab_ = settings.value(QStringLiteral("SwitchToNewTab"), false).toBool();
     reopenLastTabs_ = settings.value(QStringLiteral("ReopenLastTabs"), false).toBool();
     tabPaths_ = settings.value(QStringLiteral("TabPaths")).toStringList();
+    splitViewTabsNum_ = settings.value(QStringLiteral("SplitViewTabsNum")).toInt();
     splitterPos_ = settings.value(QStringLiteral("SplitterPos"), 150).toInt();
     sidePaneVisible_ = settings.value(QStringLiteral("SidePaneVisible"), true).toBool();
     sidePaneMode_ = sidePaneModeFromString(settings.value(QStringLiteral("SidePaneMode")).toString());
@@ -496,6 +497,7 @@ bool Settings::saveFile(QString filePath) {
     settings.setValue(QStringLiteral("SwitchToNewTab"), switchToNewTab_);
     settings.setValue(QStringLiteral("ReopenLastTabs"), reopenLastTabs_);
     settings.setValue(QStringLiteral("TabPaths"), tabPaths_);
+    settings.setValue(QStringLiteral("SplitViewTabsNum"), splitViewTabsNum_);
     settings.setValue(QStringLiteral("SplitterPos"), splitterPos_);
     settings.setValue(QStringLiteral("SidePaneVisible"), sidePaneVisible_);
     settings.setValue(QStringLiteral("SidePaneMode"), QString::fromUtf8(sidePaneModeToString(sidePaneMode_)));
@@ -812,7 +814,7 @@ static const char* wallpaperModeToString(int value) {
     return ret;
 }
 
-static int wallpaperModeFromString(const QString str) {
+int Settings::wallpaperModeFromString(const QString str) {
     int ret;
     if(str == QLatin1String("stretch")) {
         ret = DesktopWindow::WallpaperStretch;
