@@ -168,6 +168,7 @@ public:
 
     static QString xdgUserConfigDir();
     static const QList<int> & iconSizes(IconType type);
+    static int wallpaperModeFromString(const QString str);
 
     QString profileDir(QString profile, bool useFallback = false);
 
@@ -470,6 +471,14 @@ public:
         reopenLastTabs_ = reopenLastTabs;
     }
 
+    int splitViewTabsNum() const {
+        return splitViewTabsNum_;
+    }
+
+    void setSplitViewTabsNum(int n) {
+        splitViewTabsNum_ = n;
+    }
+
     QStringList tabPaths() const {
         return tabPaths_;
     }
@@ -1096,6 +1105,7 @@ private:
     bool showTabClose_;
     bool switchToNewTab_;
     bool reopenLastTabs_;
+    int splitViewTabsNum_; // number of tabs in the first view frame when reopening last tabs
     QStringList tabPaths_;
     bool rememberWindowSize_;
     int fixedWindowWidth_;
