@@ -37,8 +37,15 @@ public:
 
     void setDetachable(bool detachable) {
         detachable_ = detachable;
+        // also, reset drag info
+        dragStarted_ = false;
+        dragStartPosition_ = QPoint();
     }
 
+    // An object property used for knowing whether
+    // a tab is dropped into one of our windows:
+    static const char* tabDropped;
+
 Q_SIGNALS:
     void tabDetached();
 
