@@ -34,6 +34,7 @@
 #include <QLabel>
 #include <QToolTip>
 #include <QDir>
+#include <QStandardPaths>
 #include "settings.h"
 #include "application.h"
 #include "desktopentrydialog.h"
@@ -420,7 +421,7 @@ void TabPage::onFilesAdded(Fm::FileInfoList files) {
         }
     }
 
-    // trust the files that are added by ceateShortcut()
+    // trust the files that are added by createShortcut()
     if(!filesToTrust_.isEmpty()) {
         for(const auto& file : files) {
             const QString fileName = QString::fromStdString(file->name());
@@ -435,15 +436,38 @@ void TabPage::onFilesAdded(Fm::FileInfoList files) {
     }
 }
 
+void TabPage::localizeTitle(const Fm::FilePath& path) {
+    // force localization on some locations (FIXME: localize them in libfm-qt?)
+    if(!path.isNative()) {
+        if(path.hasUriScheme("search")) {
+            title_ = tr("Search Results");
+        }
+        else if(strcmp(path.toString().get(), "menu://applications/") == 0) {
+            title_ = tr("Applications");
+        }
+        else if(!path.hasParent()) {
+            if(path.hasUriScheme("computer")) {
+                title_ = tr("Computer");
+            }
+            else if(path.hasUriScheme("network")) {
+                title_ = tr("Network");
+            }
+            else if(path.hasUriScheme("trash")) {
+                title_ = tr("Trash");
+            }
+        }
+    }
+    else if(QString::fromUtf8(path.toString().get()) ==
+            QStandardPaths::writableLocation(QStandardPaths::DesktopLocation)) {
+        title_ = tr("Desktop");
+    }
+}
+
 void TabPage::onFolderFinishLoading() {
     auto fi = folder_->info();
     if(fi) { // if loading of the folder fails, it's possible that we don't have FmFileInfo.
-        if(folder_->path().hasUriScheme("search")) {
-            title_ = tr("Search Results"); // FIXME: Localize it in libfm-qt!
-        }
-        else {
-            title_ = fi->displayName();
-        }
+        title_ = fi->displayName();
+        localizeTitle(folder_->path());
         Q_EMIT titleChanged();
     }
 
@@ -657,6 +681,7 @@ void TabPage::chdir(Fm::FilePath newPath, bool addHistory) {
     QToolTip::showText(QPoint(), QString());
     // set title as with path button (will change if the new folder is loaded)
     title_ = QString::fromUtf8(newPath.baseName().get());
+    localizeTitle(newPath);
     Q_EMIT titleChanged();
 
     folder_ = Fm::Folder::fromPath(newPath);
@@ -1060,7 +1085,7 @@ void TabPage::goToCustomizedViewSource() {
     }
 }
 
-void TabPage::ceateShortcut() {
+void TabPage::createShortcut() {
     if(folder_ && folder_->isLoaded()) {
         auto folderPath = folder_->path();
         if(folderPath && folderPath.isNative()) {
@@ -1074,8 +1099,10 @@ void TabPage::ceateShortcut() {
                 }
             });
             dlg->show();
-            dlg->raise();
-            dlg->activateWindow();
+            if(!static_cast<Application*>(qApp)->underWayland()) {
+                dlg->raise();
+                dlg->activateWindow();
+            }
         }
     }
 }
