@@ -285,7 +285,7 @@ public:
 
     void backspacePressed();
 
-    void ceateShortcut();
+    void createShortcut();
 
     void setFilesToSelect(const Fm::FilePathList& files) {
         filesToSelect_ = files;
@@ -313,6 +313,7 @@ protected Q_SLOTS:
 private:
     void freeFolder();
     QString formatStatusText();
+    void localizeTitle(const Fm::FilePath& path);
 
     void onFolderStartLoading();
     void onFolderFinishLoading();
